@@ -102,10 +102,11 @@ def read_merchant_acct(merchant_acct_code, reference_code):
             with db_client.context():
                 merchant_acct   = MerchantAcct.get_by_account_code(merchant_acct_code)
                 logger.debug('merchant_acct=%s', merchant_acct)
-                user_acct       = User.get_by_reference_code(reference_code)
-                logger.debug('user_acct=%s', user_acct)
+                #user_acct       = User.get_by_reference_code(reference_code)
+                customer = Customer.get_by_reference_code(reference_code, merchant_acct)
+                #logger.debug('user_acct=%s', user_acct)
                 #logger.debug('industry=%s', merchant_acct.industry)
-                merchant_info = merchant_helpers.construct_merchant_acct_info(merchant_acct, referrer_code = user_acct.referral_code) 
+                merchant_info = merchant_helpers.construct_merchant_acct_info(merchant_acct, customer = customer) 
                 logger.debug('merchant_info.industry_type=%s', merchant_info.get('industry_type'))
                 
                 merchant_rating_result  = MerchantRatingResult.get_by_merchant_acct(merchant_acct)
@@ -175,7 +176,7 @@ def read_customer_brief_and_merchant_acct_and_referred_code(request_values, merc
     if is_not_empty(merchant_acct_code):
         try:
             with db_client.context():
-                merchant_info   = merchant_helpers.construct_merchant_acct_info(merchant_acct, referrer_code=referrer_code) 
+                merchant_info   = merchant_helpers.construct_merchant_acct_info(merchant_acct, customer=customer_acct) 
                 referrer_user   = User.get_by_referral_code(referrer_code)
                 '''
                 if merchant_info and referrer_user:
@@ -276,7 +277,7 @@ def read_joined_brand_details(merchant_acct_code, reference_code):
                 customer                = Customer.get_by_reference_code(reference_code, merchant_acct)
                 if customer:
                     user_acct               = customer.registered_user_acct
-                    merchant_info           = merchant_helpers.construct_merchant_acct_info(merchant_acct, referrer_code=user_acct.referral_code) 
+                    merchant_info           = merchant_helpers.construct_merchant_acct_info(merchant_acct, customer=customer) 
                     merchant_rating_result  = MerchantRatingResult.get_by_merchant_acct(merchant_acct)
                     '''
                     if merchant_info.get('referral_program_settings'):
@@ -364,12 +365,21 @@ def read_customer_details(merchant_acct_code, reference_code):
             db_client = create_db_client(caller_info="read_customer_details")
             with db_client.context():
                 merchant_acct           = MerchantAcct.get_by_account_code(merchant_acct_code)
-                
+                user_details            = None
                 logger.info('merchant_acct.brand_name=%s', merchant_acct.brand_name)
                 
                 customer                = Customer.get_by_reference_code(reference_code, merchant_acct)
+                
+                if customer is None:
+                    user_details = User.get_by_reference_code(reference_code)
+                    if user_details:
+                        hq_outlet = Outlet.get_head_quarter_outlet(merchant_acct)
+                        customer = Customer.create_from_user(hq_outlet, user_details, )
+                
                 if customer:
-                    user_details                                   = customer.registered_user_acct
+                    if user_details is None:
+                        user_details                                   = customer.registered_user_acct
+                        
                     customer_details = customer.to_dict(
                                                     date_format="%d-%m-%Y", 
                                                     datetime_format="%d-%m-%Y %H:%M:%S",
