@@ -10,13 +10,13 @@ from trexlib.utils.crypto_util import decrypt_json
 import logging
 from datetime import datetime
 from trexlib.utils.log_util import get_tracelog
-from trexadmin.libs.http import create_rest_message, StatusCode
 from trexmodel.models.datastore.loyalty_models import LoyaltyDeviceSetting
 from trexmodel.models.datastore.pos_models import POSSetting
 from trexmodel.utils.model.model_util import create_db_client
 from trexmodel.models.datastore.user_models import User
 from trexapi.conf import API_ERR_CODE_INVALID_SESSION,\
     API_ERR_CODE_EXPIRED_SESSION, API_ERR_CODE_DUPLICATED_SESSION
+from trexapi.utils.api_helpers import create_api_message, StatusCode
 
 #logger = logging.getLogger('decorator')
 logger = logging.getLogger('target_debug')
@@ -65,18 +65,18 @@ def auth_token_required(f):
                     else:
                         logger.debug('auth token is not logger valid')
                         
-                        return create_rest_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED,)
+                        return create_api_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED,)
                 else:
-                    return create_rest_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED,)
+                    return create_api_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED,)
         
-        return create_rest_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED,)
+        return create_api_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED,)
 
     return decorated_function
 
 def show_request_info(f):
     @wraps(f)
     def decorated_function(*args, **kwargs):
-        logger.info('----------------------------->>>>> request url=%s, method=%s', request.url, request.method)
+        logger.info('----------------------------->>>>> request url=%s, method=%s, function=%s', request.url, request.method, f.__name__)
         return f(*args, **kwargs)
     
     return decorated_function
@@ -107,7 +107,7 @@ def user_auth_token_required_and_check_duplicated_session(check_duplicated_sessi
                     
                 except:
                     logger.error('Failed due to %s', get_tracelog())
-                    return create_rest_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
+                    return create_api_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
                 
                 
                 
@@ -142,7 +142,7 @@ def user_auth_token_required_and_check_duplicated_session(check_duplicated_sessi
                             else:
                                 logger.debug('auth token is not logger valid, due to request device id is not same as latest device id')
                             
-                                return create_rest_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_DUPLICATED_SESSION)
+                                return create_api_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_DUPLICATED_SESSION)
                             
                             
                             
@@ -150,13 +150,13 @@ def user_auth_token_required_and_check_duplicated_session(check_duplicated_sessi
                             logger.debug('auth token is not logger valid')
                             
                             #return ("Authenticated token is expired", 401)
-                            return create_rest_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_EXPIRED_SESSION)
+                            return create_api_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_EXPIRED_SESSION)
                 else:
                     #return ("Authenticated token is invalid", 401)    
-                    return create_rest_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_INVALID_SESSION)
+                    return create_api_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_INVALID_SESSION)
             
             #return ("Authenticated token is required", 401)
-            return create_rest_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED, )
+            return create_api_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED, )
             
         return decorated_function
         '''
@@ -189,7 +189,7 @@ def _user_auth_token_required_decorated_function(f, check_duplicated_session=Fal
                 
             except:
                 logger.error('Failed due to %s', get_tracelog())
-                return create_rest_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
+                return create_api_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
             
             
             
@@ -228,7 +228,7 @@ def _user_auth_token_required_decorated_function(f, check_duplicated_session=Fal
                             else:
                                 logger.debug('auth token is not logger valid, due to request device id is not same as latest device id')
                             
-                                return create_rest_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_DUPLICATED_SESSION)
+                                return create_api_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_DUPLICATED_SESSION)
                         
                         else:
                             #return f(*(user_reference_code, *args), **kwargs)
@@ -239,20 +239,22 @@ def _user_auth_token_required_decorated_function(f, check_duplicated_session=Fal
                         logger.debug('auth token is not logger valid')
                         
                         #return ("Authenticated token is expired", 401)
-                        return create_rest_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_EXPIRED_SESSION)
+                        return create_api_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_EXPIRED_SESSION)
             else:
                 #return ("Authenticated token is invalid", 401)    
-                return create_rest_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_INVALID_SESSION)
+                return create_api_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_INVALID_SESSION)
         
         #return ("Authenticated token is required", 401)
-        return create_rest_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED, )
+        return create_api_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED, )
 
     return decorated_function
 
 def user_auth_token_required_pass_reference_code(f):
+    logger.debug("Calling function: %s", f.__name__)
     return _user_auth_token_required_decorated_function(f, check_duplicated_session=False, pass_reference_code=True)
 
 def user_auth_token_required(f):
+    logger.debug("Calling function: %s", f.__name__)
     return _user_auth_token_required_decorated_function(f, check_duplicated_session=False, pass_reference_code=False)
     '''
     @wraps(f)
@@ -278,7 +280,7 @@ def user_auth_token_required(f):
                 
             except:
                 logger.error('Failed due to %s', get_tracelog())
-                return create_rest_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
+                return create_api_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
             
             
             
@@ -315,7 +317,7 @@ def user_auth_token_required(f):
                             else:
                                 logger.debug('auth token is not logger valid, due to request device id is not same as latest device id')
                             
-                                return create_rest_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_DUPLICATED_SESSION)
+                                return create_api_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_DUPLICATED_SESSION)
                         
                         else:
                             return f(*(user_reference_code, *args), **kwargs)
@@ -324,13 +326,13 @@ def user_auth_token_required(f):
                         logger.debug('auth token is not logger valid')
                         
                         #return ("Authenticated token is expired", 401)
-                        return create_rest_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_EXPIRED_SESSION)
+                        return create_api_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_EXPIRED_SESSION)
             else:
                 #return ("Authenticated token is invalid", 401)    
-                return create_rest_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_INVALID_SESSION)
+                return create_api_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED, error_code=API_ERR_CODE_INVALID_SESSION)
         
         #return ("Authenticated token is required", 401)
-        return create_rest_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED, )
+        return create_api_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED, )
         '''
     return decorated_function
 
@@ -353,7 +355,7 @@ def verify_device(f):
                 
             except:
                 logger.error('Failed due to %s', get_tracelog())
-                return create_rest_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
+                return create_api_message('Authenticated token is not valid', status_code=StatusCode.UNAUTHORIZED,)
             
             
             
@@ -385,19 +387,19 @@ def verify_device(f):
                         else:
                             logger.debug('auth token is not logger valid, due to ')
                         
-                            return create_rest_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED,)
+                            return create_api_message('Authenticated token is not longer valid', status_code=StatusCode.UNAUTHORIZED,)
                         
                     else:
                         logger.debug('auth token is not logger valid')
                         
                         #return ("Authenticated token is expired", 401)
-                        return create_rest_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED,)
+                        return create_api_message('Authenticated token is expired', status_code=StatusCode.UNAUTHORIZED,)
             else:
                 #return ("Authenticated token is invalid", 401)    
-                return create_rest_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED,)
+                return create_api_message('Authenticated token is invalid', status_code=StatusCode.UNAUTHORIZED,)
         
         #return ("Authenticated token is required", 401)
-        return create_rest_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED,)
+        return create_api_message('Authenticated token is required', status_code=StatusCode.UNAUTHORIZED,)
 
     return decorated_function
 
@@ -449,17 +451,17 @@ def device_is_activated(f):
                         else:
                             if device_settings.device_id != device_id:
                                 logger.info('Access device id is not same as activation device id')
-                                return create_rest_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
+                                return create_api_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
                             
                             logger.info('Access device id is authorized')
                         return f(*args, **kwargs)
                     
-                    return create_rest_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
+                    return create_api_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
                     
                 except:
                     logger.error('failed due to %s ', get_tracelog())
                     #return ("Failed to check device authorization", 401)
-                    return create_rest_message('Failed to check device authorization', status_code=StatusCode.BAD_REQUEST)
+                    return create_api_message('Failed to check device authorization', status_code=StatusCode.BAD_REQUEST)
                 
         
             
@@ -494,19 +496,19 @@ def device_activated_is_required(f):
                     else:
                         if device_settings.device_id != device_id:
                             logger.info('Access device id is not same as activation device id')
-                            return create_rest_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
+                            return create_api_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
                     
                     return f(*(activation_code, *args), *args, **kwargs)
                 
-                return create_rest_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
+                return create_api_message('Device is not activated or it is deactivated already', status_code=StatusCode.BAD_REQUEST)
                 
             except:
                 logger.error('failed due to %s ', get_tracelog())
                 #return ("Failed to check device authorization", 401)
-                return create_rest_message('Failed to check device is activated', status_code=StatusCode.BAD_REQUEST)
+                return create_api_message('Failed to check device is activated', status_code=StatusCode.BAD_REQUEST)
             
         else:  
-            return create_rest_message('Missing activation code, or device type or device id', status_code=StatusCode.BAD_REQUEST)  
+            return create_api_message('Missing activation code, or device type or device id', status_code=StatusCode.BAD_REQUEST)  
 
     return decorated_function
 
@@ -523,7 +525,7 @@ def outlet_key_required(f):
             
         
         #return ("Outlet Key is required", 401)
-        return create_rest_message('Missing outlet key', status_code=StatusCode.UNAUTHORIZED)
+        return create_api_message('Missing outlet key', status_code=StatusCode.UNAUTHORIZED)
 
     return decorated_function
 
@@ -540,7 +542,7 @@ def merchant_key_required(f):
             
         
         #return ("Merchant account id is required", 401)
-        return create_rest_message('Missing merchant account id', status_code=StatusCode.UNAUTHORIZED)
+        return create_api_message('Missing merchant account id', status_code=StatusCode.UNAUTHORIZED)
 
     return decorated_function
 
@@ -557,7 +559,7 @@ def customer_key_required(f):
             
         
         #return ("Outlet Key is required", 401)
-        return create_rest_message('Missing customer key', status_code=StatusCode.UNAUTHORIZED)
+        return create_api_message('Missing customer key', status_code=StatusCode.UNAUTHORIZED)
 
     return decorated_function
 
